=======
sm2rain
=======

.. image:: https://travis-ci.org/IRPIhydrology/sm2rain.svg?branch=master
    :target: https://travis-ci.org/IRPIhydrology/sm2rain

.. image:: https://coveralls.io/repos/github/IRPIhydrology/sm2rain/badge.svg?branch=master
   :target: https://coveralls.io/github/IRPIhydrology/sm2rain?branch=master

.. image:: https://readthedocs.org/projects/sm2rain/badge/?version=latest
   :target: http://sm2rain.readthedocs.org/

Implementation of the SM2Rain algorithm.


Description
===========

Soil moisture time series are converted into rainfall.


Note
====

This project has been set up using PyScaffold 2.5.11. For details and usage
information on PyScaffold see http://pyscaffold.readthedocs.org/.
